@@ -4,17 +4,17 @@
 #'
 #'
 #' @examples
-#' head(climate)
-"climate"
+#' head(climate_indices)
+"climate_indices"
 
-#' Stock index
+#' Dow Jones stock price
 #'
-#' This is a time series of stock series which contains AAPL and MSFT from March 13, 1986 to August 6, 2018.
+#' It includes 29 time series of stock series in Dow Jones.
 #'
 #'
 #' @examples
-#' head(stock)
-"stock"
+#' head(DJS)
+"DJS"
 
 #' A data from Illapel
 #'
